@@ -5,6 +5,7 @@ import aio_pika
 import logging
 import copy
 from typing import Optional
+from aiormq.exceptions import ChannelNotFoundEntity
 from aio_pika import Channel, Queue, Exchange, ExchangeType
 import constants.rmq_config as rmq_config
 from .abstract_rmq_consumer import RabbitMQConsumer
@@ -124,12 +125,19 @@ async def send_message(msg_data, exchange_name, routing_key, host, port, login,
     )
     async with connection:
         channel = await connection.channel()
-        exchange = await channel.get_exchange(exchange_name)
-        msg = aio_pika.Message(body=msg_data)
-        await exchange.publish(
-            msg,
-            routing_key=routing_key
-        )
+
+        try:
+            exchange = await channel.get_exchange(exchange_name)
+            msg = aio_pika.Message(body=msg_data)
+            await exchange.publish(
+                msg,
+                routing_key=routing_key
+            )
+
+        except ChannelNotFoundEntity:
+            logger.warning("The message could not be sent because the exchange with the name '%s' was not found"
+                           % exchange_name)
+
 
 def get_exchange_type(s):
     if s == ExchangeType.DIRECT.value:
